Derive Macros
- Autobox
- Takes a given enum (which in turn accepts child enums) and auto generates a
Parent::Fromso the child can turn into the parent and aTryInto<Child> for Parentso the Parent can attempt to turn into the child. - MechErr
- ToSubstance